@@ -431,18 +431,102 @@ where I have assumed that all configurations are of [Extended XYZ format](https:
 It is very easy to, however, load in a different format. For example, replace `"extxyz"` with `"vasp"` if you have `POSCAR` files 
 generated by VASP, or with `"lammps-data"` if you have LAMMPS data files. There is quite a large set of supported formats, 
 which you can find [here](https://ase-lib.org/ase/io/io.html#ase.io.read).
+
+## Fitting with an intercept → MC
+
+If you choose to fit using `scikit-learn`, models will include an intercept by default. This is not a problem if you
+just want to compute energies, but you likely want to feed this into `tce.monte_carlo.monte_carlo` later, which expects a linear 
+transformation, rather than an affine transformation.
+
+If your model is affine, i.e. includes an intercept:
+
+$$ f(\mathbf{t}) = \alpha + \boldsymbol{\beta}^\intercal\mathbf{t} $$
+
+Then, the resulting energy difference will be computed as:
+
+$$ f(\Delta\mathbf{t}) = \alpha + \boldsymbol{\beta}^\intercal\Delta\mathbf{t} $$
+
+which is invalid unless $\alpha = 0$. `tce.monte_carlo.monte_carlo` will warn the user if they input a `model` argument that has 
+a nonzero `.intercept_` attribute like `sklearn` models do.
+
+For simple models, e.g. if you train using `sklearn.linear_model.LinearRegression`, you  can simply ignore the intercept term 
+during training:
+
+```py
+from tce.training import train
+from sklearn.linear_model import LinearRegression
+
+ce = train(
+    configurations=...
+    basis=...
+    model=LinearRegression(fit_intercept=False)    
+)
+```
+
+However, it is often the case that results are extremely sensitive on the individual interaction energies. In this case, ones first 
+instinct is to use PCA to reduce the feature space dimensionality, and to scale the features to have zero mean and unit variance:
+
+```py
+from tce.training import train
+from sklearn.linear_model import LinearRegression
+from sklearn.decomposition import PCA
+from sklearn.preprocessing import StandardScaler
+from sklearn.pipeline import Pipeline
+
+ce = train(
+    configurations=...
+    basis=...
+    model=Pipeline([
+        ("scale", StandardScaler()),
+        ("reduce", PCA(n_components=...)),
+        ("fit", LinearRegression(fit_intercept=False))
+    ]) 
+)
+```
+
+However, this routine is almost certain to produce garbage results, and for a very subtle reason. Both `StandardScaler` and `PCA` 
+recenter the data to have zero mean, which introduces an intercept. This can be changed within `StandardScaler`, but not `PCA`. 
+We need to make sure that the data is not recentered, and that we replace `PCA` with a decomposition method that also does 
+not recenter the data, such as `TruncatedSVD`:
+
+```py
+from tce.training import train
+from sklearn.linear_model import LinearRegression
+from sklearn.decomposition import TruncatedSVD
+from sklearn.preprocessing import StandardScaler
+from sklearn.pipeline import Pipeline
+
+ce = train(
+    configurations=...
+    basis=...
+    model=Pipeline([
+        ("scale", StandardScaler(with_mean=False)),
+        ("reduce", TruncatedSVD(n_components=...)),
+        ("fit", LinearRegression(fit_intercept=False))
+    ]) 
+)
+```
+
+Of course, you can replace `sklearn.linear_model.LinearRegression` with something more robust, e.g. 
+`sklearn.linear_model.ElasticNetCV`, which uses [elastic net regularization](https://en.wikipedia.org/wiki/Elastic_net_regularization) 
+and [leave-one-out cross validation](https://www.statology.org/leave-one-out-cross-validation/).
+
 """
 
-__version__ = "0.7.2"
+__version__ = "0.8.4"
 __authors__ = ["Jacob Jeffries"]
 
 __url__ = "https://github.com/MUEXLY/tce-lib"
 
 import warnings
 
+from . import calculator as calculator
 from . import constants as constants
+from . import datasets as datasets
+from . import monte_carlo as monte_carlo
 from . import structures as structures
 from . import topology as topology
+from . import training as training
 
 
 if __version__.startswith("0."):
